==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/Output/alsa/translations/alsa_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="32"/>
        <source>ALSA Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>About ALSA Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Output/alsa/translations/alsa_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="32"/>
        <source>ALSA Plugin</source>
        <translation>Plugin ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>About ALSA Output Plugin</source>
        <translation>Sobre o puglin de saída ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Plugin de saída Qmmp ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Definições do dispositivo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Dispositivo de áudio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Mixador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Placa mixadora:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Dispositivo mixador:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Configurações avançadas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Placa de som</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Tempo de armazenamento (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Período (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>Usar acesso mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Usar função snd_pcm_pause</translation>
    </message>
</context>
</TS>
